using System;
using System.ComponentModel;
using System.Reflection;

namespace SharePointArchitects.FilePlanner
{
	/// <summary>
	/// Utility class for extracting descriptions from enumerators.
	/// </summary>
	/// <remarks>Uses reflection to extract the DescriptionAttribute from an enumerator.  
	/// Returns the enumerator type if no DescriptionAttribute is found.</remarks>
	public class EnumDescription {
		private string m_str="";
		///<summary>Constructor from a given enumerator value.</summary>
		public EnumDescription(Enum value) {
			DescriptionAttribute attrib	= 
				Attribute.GetCustomAttribute(value.GetType().GetField(value.ToString()),
				typeof(DescriptionAttribute)) as DescriptionAttribute;
			m_str = (attrib == null) ? value.ToString() : attrib.Description;
		}
		///<summary>Provides support for implicit string conversion.</summary>
		public static implicit operator string(EnumDescription s) {
			return s.m_str;
		}
		///<summary>Provides support for explicit string conversion.</summary>
		public override string ToString() {
			return m_str;
		}
	}

}
