using System;
using System.ComponentModel;
using System.Reflection;

namespace SharePointArchitects.FilePlanner
{
	/// <summary>
	/// Utility class for extracting labels from enumerators.
	/// </summary>
	/// <remarks>Uses reflection to extract the LabelAttribute from an enumerator.  
	/// Returns the enumerator type if no LabelAttribute is found.</remarks>
	public class EnumLabel {
		private string m_str="";
		///<summary>Constructor from a given enumerator value.</summary>
		public EnumLabel(Enum value) {
			LabelAttribute attrib = 
				Attribute.GetCustomAttribute(value.GetType().GetField(value.ToString()),
				typeof(LabelAttribute))	as LabelAttribute;
			m_str = (attrib == null) ? value.ToString() : attrib.Label;
		}
		///<summary>Provides support for implicit string conversion.</summary>
		public static implicit operator string(EnumLabel s) {
			return s.m_str;
		}
		///<summary>Provides support for explicit string conversion.</summary>
		public override string ToString() {
			return m_str;
		}
	}
}
