﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Publishing.Internal;

namespace SPC2011.FilePlanner
{
    /// <summary>
    /// Implements a long-running job that provisions and configures
    /// a records center site based on a File Plan.
    /// </summary>
    public class FilePlanActivationJob : LongRunningOperationJob
    {
        SPWeb Web = null;
        FilePlan Plan = null;
        FilePlanSettings Settings = FilePlanSettings.Default;

        public FilePlanActivationJob(SPWeb web, FilePlan filePlan, FilePlanSettings settings)
        {
            Web = web;
            Plan = filePlan;
            Settings = settings;
            Title = string.Format("Activating file plan '{0}'", Plan.Title);
            StatusDescription = Title;
            GearsImageUrl = "~/_layouts/images/gears_an.gif";
        }

        public static FilePlanActivationJob Create(SPWeb web, FilePlan filePlan, FilePlanSettings settings)
        {
            FilePlanActivationJob job = new FilePlanActivationJob(web, filePlan, settings);
            job.WaitMessage = "Please wait while the file plan is activated...";
            job.RedirectWhenFinished = true;
            job.NavigateWhenDoneUrl = web.Url;
            job.UserCanCancel = false;
            job.MillisecondsToWaitForFinish = 5000;
            job.TotalOperationsToBePerformed = 6;
            job.Start(web);
            return job;
        }

        // Perfor
        public override void DoWork()
        {
            CreateWebApplication();
            CreateRecordsCenterSiteCollection();
            CreateInformationPolicies();
            CreateContentTypes();
            CreateDocumentLibraries();
            CreateContentOrganizerRules();
            UpdateStatus();
        }

        void StartOperation(string status)
        {
            StatusDescription = status;
            UpdateStatus();
            OperationsPerformed++;
        }

        void HandleException(Exception exception, string format, params object[] args)
        {
            SetError(exception, string.Format(format, args));
        }

        void CreateWebApplication()
        {
            StartOperation("Creating web application.");
            try
            {
            }
            catch (Exception x)
            {
                HandleException(x, "Failed to create web application");
            }
        }

        void CreateRecordsCenterSiteCollection()
        {
            StartOperation("Creating records center site collection...");
            try
            {
            }
            catch (Exception x)
            {
                HandleException(x, "Failed to create site collection");
            }
        }

        void CreateInformationPolicies()
        {
            StartOperation("Creating information policies...");
            try
            {
            }
            catch (Exception x)
            {
                HandleException(x, "Failed to create information policies");
            }
        }

        void CreateContentTypes()
        {
            StartOperation("Creating content types...");
            try
            {
            }
            catch (Exception x)
            {
                HandleException(x, "Failed to create content types");
            }
        }

        void CreateDocumentLibraries()
        {
            StartOperation("Creating document libraries...");
            try
            {
            }
            catch (Exception x)
            {
                HandleException(x, "Failed to create document libraries");
            }
        }

        void CreateContentOrganizerRules()
        {
            StartOperation("Creating content organizer rules...");
            try
            {
            }
            catch (Exception x)
            {
                HandleException(x, "Failed to create content organizer rules");
            }
        }
    }
}
