﻿using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Security;
using System.Linq;
using System.Text;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Administration;

namespace SharePointArchitects.FilePlanner
{
    // Specifies various options for provisioning a records center
    // based on a file plan.
    public class FilePlanSettings
    {
        public string Url { get; set; }
        public string Title { get; set; }
        public string Description { get; set; }
        public string ApplicationPoolName { get; set; }
        public string AdministratorLogin { get; set; }
        public string AdministratorPassword { get; set; }
        public string AdministratorEmail { get; set; }
        public string AdministratorDisplayName { get; set; }
        public int PortNumber { get; set; }
        public bool NewDatabase { get; set; }
        public bool SSLEnabled { get; set; }
        public bool EnableSubsites { get; set; }
        public bool SeparateDatabase { get; set; }
        public IdentityType IdentityType { get; set; }
        public RecordGroupingStrategy RecordGrouping { get; set; }

        /// <summary>
        /// Protected constructor.
        /// </summary>
        protected FilePlanSettings(){}

        /// <summary>
        /// Setup default values for the File Plan settings.
        /// </summary>
        public static FilePlanSettings Default
        {
            get
            {
                FilePlanSettings settings = new FilePlanSettings();
                settings.EnableSubsites = false;
                settings.PortNumber = 9000;
                settings.NewDatabase = true;
                settings.SSLEnabled = false;
                settings.SeparateDatabase = true;
                settings.IdentityType = IdentityType.SpecificUser;
                settings.ApplicationPoolName = "RecordsManagementAppPool";
                settings.AdministratorLogin = "Administrator";
                settings.AdministratorPassword = "Pass@word1";
                settings.AdministratorEmail = "administrator@contoso.com";
                settings.AdministratorDisplayName = "Records Administrator";
                settings.RecordGrouping = RecordGroupingStrategy.GroupByCategory;
                return settings;
            }
        }

        public string GetSafeUrl()
        {
            if (string.IsNullOrEmpty(Url))
                return "/sites/" + GetSafeTitle();
            if (Url.StartsWith("/"))
                return "/sites" + Url;
            return "/sites/" + Url;
        }

        public string GetSafeTitle()
        {
            if (string.IsNullOrEmpty(Title))
                return "RecordsCenter";
            return Title.Replace(" ", "_")
                .Replace(":","-");
        }
    }
}
