using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;

namespace SharePointArchitects.FilePlanner
{
    public enum RecordGroupingStrategy
    {
        /// <summary>
        /// Create a document library for each major category, with folders for each subcategory.  Retention is managed
        /// using content type information policies.
        /// </summary>
        [Label("Group by Category")]
        [Description("Create a document library for each major category with folders for each subcategory. Retention is managed using content type information policies.")]
        GroupByCategory,

        /// <summary>
        /// Create a document library for each major category, with folders for each subcategory.  Retention is managed
        /// at the folder level, rolling up to the longest retention period.
        /// </summary>
        [Label("Group by Category with Retention")]
        [Description("Create a document library for each major category with folder for each subcategory.  Retention is managed at the folder level, rolling up to the longest retention period.")]
        GroupByCategoryWithRetention,

        /// <summary>
        /// Create a document library for each group of roles to which record series have been assigned.  Retention is managed
        /// using content type information policies.
        /// </summary>
        [Label("Group by Responsibility")]
        [Description("Create a document library for each group of roles to which record series have been assigned.  Retention is managed using content type information policies.")]
        GroupByResponsibility,

        /// <summary>
        /// Create a document library for each group of records that share the same retention formula.
        /// </summary>
        [Label("Group by Shared Retention")]
        [Description("Create a document library for each group of records that share the same retention formula.")]
        GroupBySharedRetention,

        /// <summary>
        /// Create a document library for each category within each group of records that share the same retention formula.
        /// </summary>
        [Label("Group by Category with Shared Retention")]
        [Description("Create a document library for each category within each group of records that share the same retention formula.")]
        GroupByCategoryWithSharedRetention,

        /// <summary>
        /// Create a content type for each record series, without considering categories.  Retention is managed using
        /// content type information policies.
        /// </summary>
        [Label("Group by Record Series")]
        [Description("Create a content type for each record series, without considering categories.  Retention is managed using content type information policies.")]
        GroupByRecordSeries,

        /// <summary>
        /// Create a content type for each major category, with child content types for each subcategory.  Retention is managed
        /// using content type information policies, rolling up to the longest retention period for each type.
        /// </summary>
        [Label("Group by Content Type")]
        [Description("Create a content type for each major category, with child content types for each subcategory.  Retention is managed using content type information policies, rolling up to the longest retention period for each type.")]
        GroupByContentType
    }
}
