﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.SharePoint;
using Microsoft.Office.RecordsManagement;
using Microsoft.Office.RecordsManagement.InformationPolicy;

namespace SharePointArchitects.FilePlanner.Configuration
{
    /// <summary>
    /// Describes a SharePoint document library folder.
    /// </summary>
    public class FolderDescriptor : SharePointObjectDescriptor
    {
        public SPFolder Folder = null;
        public string Title = string.Empty;
        public List<FolderDescriptor> Folders = new List<FolderDescriptor>();
        public InformationPolicyDescriptor Policy = null;

        // Construct a folder descriptor for a given category.
        public FolderDescriptor(ContentTypeDescriptor contentType, string title, string[] categories, int categoryIndex)
        {
            Title = title.Trim().Sanitize();
            if (categoryIndex < categories.Length)
            {
                // Delegate to the next name in the list.
                Folders.Add(new FolderDescriptor(contentType, categories[categoryIndex], categories, categoryIndex + 1));
            }
            else
            {
                contentType.RoutingTargets.Add(this);
            }
        }

        // Creates the folder in the designated parent.
        // If a policy is associated with the folder, it is also created.
        // If the folder has subfolders, they are also created.
        public bool Configure(SPFolder parentFolder, out Exception exception)
        {
            exception = null;
            this.Folder = parentFolder.SubFolders.Add(Title);
            if (Policy != null)
                return Policy.Configure(this.Folder, out exception);
            foreach (FolderDescriptor folder in Folders)
                if (!folder.Configure(this.Folder, out exception))
                    return false;
            return true;
        }

        // Return the address of the actual folder when used as the
        // target of a routing rule.
        public override string RoutingRuleTargetPath
        {
            get
            {
                return Folder.ServerRelativeUrl;
            }
        }
    }
}
