﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.SharePoint;
using Microsoft.Office.RecordsManagement;
using Microsoft.Office.RecordsManagement.RecordsRepository;
using Microsoft.Office.RecordsManagement.InformationPolicy;

namespace SharePointArchitects.FilePlanner.Configuration
{
    /// <summary>
    /// Describes a SharePoint content organizer rule.
    /// </summary>
    public class RoutingRuleDescriptor : SharePointObjectDescriptor
    {
        public string Name = string.Empty;
        public ContentTypeDescriptor ContentType = null;
        public SharePointObjectDescriptor RoutingTarget = null;

        // Construct a simple routing rule for a content type.
        public RoutingRuleDescriptor(ContentTypeDescriptor contentType, SharePointObjectDescriptor routingTarget)
        {
            ContentType = contentType;
            RoutingTarget = routingTarget;
            // TODO: RoutingRuleDescriptor should act as a mapping from a content type to a routing target.
            // 
        }

        // Creates the routing rule in the specified site.
        public bool Configure(SPSite recordsCenter, out Exception exception)
        {
            exception = null;
            EcmDocumentRoutingWeb routingWeb = new EcmDocumentRoutingWeb(recordsCenter.RootWeb);
            if (routingWeb == null)
            {
                exception = new ArgumentException("Target site for routing rule is not a records center.");
                return false;
            }
            if (ContentType == null)
            {
                exception = new InvalidOperationException("Routing rule must have a content type.");
                return false;
            }
            if (RoutingTarget == null)
            {
                exception = new InvalidOperationException("Routing rule must have a  target.");
                return false;
            }
            if (ContentType.ContentType == null)
            {
                exception = new ArgumentNullException(string.Format("Cannot create routing rule because content type '{0}' was not provisioned.", ContentType.Title));
                return false;
            }
            string contentTypeIdString = ContentType.ContentType.Id.ToString() + "|" + ContentType.ContentType.Name;
            EcmDocumentRouterRule rule = new EcmDocumentRouterRule(recordsCenter.RootWeb);
            rule.Name = ContentType.Title.Sanitize();
            rule.Description = ContentType.Description;
            rule.Priority = "5";
            rule.ContentTypeString = contentTypeIdString;
            rule.TargetPath = RoutingTarget.RoutingRuleTargetPath;
            rule.Enabled = true;
            routingWeb.RoutingRuleCollection.Add(rule);
            return true;
        }
    }
}
