using System;
using System.Linq;
using System.Collections.Generic;
using System.Runtime.InteropServices;
using System.Security.Permissions;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Navigation;
using Microsoft.SharePoint.Security;

namespace SharePointArchitects.FilePlanner.Features.SharePointArchitects.FilePlanner
{
    [Guid("a5310498-7338-4624-bf74-e89639bbefd7")]
    public class SPC2011EventReceiver : SPFeatureReceiver
    {
        const string FILEPLAN_TYPENAME = "File Plan Template";
        const string FILEPLAN_GALLERYNAME = "File Plan Gallery";

        public override void FeatureActivated(SPFeatureReceiverProperties properties)
        {
            SPSite site = properties.Feature.Parent as SPSite;

            // locate the file plan content type - installed by the FilePlanForm feature

            SPContentType ctFilePlan = site.RootWeb.AvailableContentTypes[FILEPLAN_TYPENAME];

            // locate the file plan gallery and add the file plan content type

            SPList filePlanGallery = site.RootWeb.Lists[FILEPLAN_GALLERYNAME];
            filePlanGallery.ContentTypesEnabled = true;
            filePlanGallery.ContentTypes.Add(ctFilePlan);
            filePlanGallery.ContentTypes.Delete(filePlanGallery.ContentTypes[0].Id);
            filePlanGallery.Update();

            // add a custom command to the FilePlan content type ECB that enables
            // a plan administrator to activate the plan

            SPUserCustomAction action = site.RootWeb.UserCustomActions.Add();
            action.RegistrationType = SPUserCustomActionRegistrationType.ContentType;
            action.RegistrationId = ctFilePlan.Id.ToString();
            action.Location = "EditControlBlock";
            action.Sequence = 450;
            action.Title = "Activate File Plan";
            action.Rights = SPBasePermissions.EditListItems;
            action.ImageUrl = "/_layouts/images/CheckValues.gif";
            action.Url = "/_layouts/SharePointArchitects/FilePlanActivate.aspx?ItemId={ItemId}&amp;ListId={ListId}";
            action.Update();
        }

        public override void FeatureDeactivating(SPFeatureReceiverProperties properties)
        {
            SPSite site = properties.Feature.Parent as SPSite;

            // locate the file plan content type
            SPContentType ctFilePlan = site.RootWeb.AvailableContentTypes[FILEPLAN_TYPENAME];

            // remove the custom action link
            foreach (var action in site.RootWeb.UserCustomActions)
                if (action.RegistrationId.Equals(ctFilePlan.Id.ToString()))
                {
                    action.Delete();
                    site.RootWeb.Update();
                    break;
                }
        }
    }
}
