﻿using System;
using System.Web;
using System.Web.UI.WebControls;
using System.Threading;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Administration;
using Microsoft.SharePoint.WebControls;
using Microsoft.SharePoint.Utilities;
using Microsoft.Office.RecordsManagement.RecordsRepository;

namespace SharePointArchitects.FilePlanner
{
    public partial class FilePlanActivate : LayoutsPageBase
    {
        FilePlan _filePlan = null;
        FilePlanSettings _settings = FilePlanSettings.Default;

        protected void Page_Load(object sender, EventArgs e)
        {
            // get the source list from the request parameters
            string listId = Request.QueryString["ListId"];
            SPList list = Web.Lists[new Guid(listId)];

            // get the list item for the file plan to process
            string planId = Request.QueryString["ItemId"];
            SPListItem item = list.Items.GetItemById(Convert.ToInt32(planId));

            // retrieve the file plan definition
            _filePlan = FilePlan.LoadFromListItem(item);

            if (!Page.IsPostBack)
            {
                // display the plan details on the page
                FilePlanPageTitle.Text = _filePlan.Title;
                PlanTitle.Text = _filePlan.Title;
                PlanDescription.Text = _filePlan.Description;

                // display the default settings
                RecordsCenterUrl.Text = _settings.Url;

                BindWebApplicationButtons();
                BindGroupingStrategyButtons();
            }
        }

        // Initialize the web application radio button group.
        void BindWebApplicationButtons()
        {
            int index = 0;
            foreach (SPWebApplication webApp in SPWebService.ContentService.WebApplications)
            {
                if (webApp != Web.Site.WebApplication)
                {
                    ListItem item = new ListItem(webApp.DisplayName, webApp.Id.ToString());
                    item.Selected = (index == 0);
                    WebApplicationDropDownList.Items.Add(item);
                }
                index++;
            }
        }

        SPWebApplication GetSelectedWebApplication()
        {
            Guid guid = new Guid(WebApplicationDropDownList.SelectedValue);
            foreach (SPWebApplication webApp in SPWebService.ContentService.WebApplications)
                if (webApp.Id.Equals(guid))
                    return webApp;
            return null;
        }

        // Initialize the grouping strategy radio button group.
        void BindGroupingStrategyButtons()
        {
            foreach (RecordGroupingStrategy option in Enum.GetValues(typeof(RecordGroupingStrategy)))
            {
                ListItem item = new ListItem(new EnumLabel(option),option.ToString());
                item.Selected = option.Equals(RecordGroupingStrategy.GroupByRecordSeries);
                item.Attributes.Add("title", new EnumDescription(option));
                GroupingStrategyButtonList.Items.Add(item);
            }
        }

        // Activate the plan according to the specified options.
        public void BtnActivate_Click(object sender, EventArgs e)
        {
            SPSite recordsCenter = null;

            // update the settings from the page controls
            _settings.Title = PlanTitle.Text;
            _settings.Url = RecordsCenterUrl.Text;
            _settings.Description = PlanDescription.Text;
            _settings.AdministratorLogin = Web.CurrentUser.LoginName;
            _settings.AdministratorDisplayName = Web.CurrentUser.Name;
            _settings.AdministratorEmail = Web.CurrentUser.Email;
            _settings.RecordGrouping = (RecordGroupingStrategy)
                Enum.Parse(typeof(RecordGroupingStrategy), GroupingStrategyButtonList.SelectedValue);

            using (SPLongOperation operation = new SPLongOperation(Page))
            {
                bool failed = false;
                string message = "File Plan Execution Failed.";
                string url = Web.Url;

                operation.Begin();

                try
                {
                    // get the selected web application
                    SPWebApplication webApplication = GetSelectedWebApplication();

                    // provision the records center in this web application
                    recordsCenter = _filePlan.Provision(webApplication, _settings);
                }
                catch (Exception x)
                {
                    failed = true;
                    message = string.Format(
                        "Exception occurred during file plan activation: {0}",
                        x.Message);
                }

                if (recordsCenter != null)
                    url=recordsCenter.RootWeb.Url;

                if (failed)
                    url = string.Format("/_layouts/error.aspx?ErrorText={0}", message);

                operation.End(url);
            }
        }
    }
}
